@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2006 by Georg Hennig                               *
+ *   Copyright (C) 2005-2007 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -415,6 +415,8 @@ QValueList<int> KomparatorFileFilter::getIntList()
 		ret.push_back( m_newer_equal->isChecked() ? 1 : 0 );
 		ret.push_back( m_newer_same_time->isChecked() ? 1 : 0 );
 	}
+	ret.push_back( m_auto_apply ? 1 : 0 );
+
 	return ret;
 }
 
@@ -430,9 +432,9 @@ void KomparatorFileFilter::setStringList( QStringList &string_list )
 
 void KomparatorFileFilter::setIntList( QValueList<int> &int_list )
 {
-	if ( ( m_filter_type == DUPLICATES_TYPE && int_list.size() != 10 ) ||
-		( m_filter_type == NEWER_TYPE && int_list.size() != 11 ) ||
-		( m_filter_type == MISSING_TYPE && int_list.size() != 8 ) ) return;
+	if ( ( m_filter_type == DUPLICATES_TYPE && int_list.size() != 11 ) ||
+		( m_filter_type == NEWER_TYPE && int_list.size() != 12 ) ||
+		( m_filter_type == MISSING_TYPE && int_list.size() != 9 ) ) return;
 
 	m_min_size->setValue( int_list[0] );
 	m_min_size_combo->setCurrentItem( int_list[1] );
@@ -446,11 +448,13 @@ void KomparatorFileFilter::setIntList( QValueList<int> &int_list )
 	{
 		m_duplicates_normal->setChecked( (bool)int_list[8] );
 		m_duplicates_multiple->setChecked( (bool)int_list[9] );
+		m_auto_apply = (bool)int_list[10];
 	}
 	else if ( m_filter_type == NEWER_TYPE )
 	{
 		m_newer_real->setChecked( int_list[8] );
 		m_newer_equal->setChecked( int_list[9] );
 		m_newer_same_time->setChecked( int_list[10] );
+		m_auto_apply = (bool)int_list[11];
 	}
 }
