@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2006 by Georg Hennig                               *
+ *   Copyright (C) 2005-2007 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -35,6 +35,7 @@
 
 #include "kdatecombo.h"
 #include "komparatorfilefilter.h"
+#include "komparatorurllist.h"
 #include "komparatorwidget.h"
 
 #include "komparatorpreset.h"
@@ -65,6 +66,7 @@ KomparatorPreset::KomparatorPreset( KomparatorWidget *_parent )
 	m_md5_sum = true;
 	m_binary_comparison = false;
 	m_binary_comparison_size = 10; // in MB
+	m_duplicates_right_url_only = false;
 	m_empty_folders = false;
 	m_include_subfolders = true;
 	m_include_hidden_items = true;
@@ -75,48 +77,66 @@ KomparatorPreset::KomparatorPreset( KomparatorWidget *_parent )
 	m_enable_missing_search = true;
 	m_enable_newer_search = true;
 	m_reference_folder_left = true;
+
 	int i;
 	for ( i=0; i<24; i++ ) m_filter_string.push_back( "" ); // name, path, owner, group from duplicates1, 2, missing1, 2, newer1, 2.
-	for ( i=0; i<56; i++ ) m_filter_int.push_back( 0 ); // All other entries. Bool is 1 or 0, Date is Year, Month, Day.
+	m_filter_string.push_back( "EOL" );
+	for ( i=0; i<62; i++ ) m_filter_int.push_back( 0 ); // All other entries. Bool is 1 or 0, Date is Year, Month, Day.
+
 	// set correct default values now:
-	m_filter_int[2] = 9999; // duplicates1: 0..9
+	// 0 and 1: min size, min size unit
+	m_filter_int[2] = 9999; // duplicates1: 0..10
 	m_filter_int[3] = 2;
+	// 4: date check box
 	m_filter_int[5] = QDate::currentDate().year();
 	m_filter_int[6] = QDate::currentDate().month();
 	m_filter_int[7] = QDate::currentDate().day();
 	m_filter_int[8] = 1;
 	m_filter_int[9] = 1;
-	m_filter_int[12] = 9999; // duplicates2: 10..17
-	m_filter_int[13] = 2;
-	m_filter_int[15] = QDate::currentDate().year();
-	m_filter_int[16] = QDate::currentDate().month();
-	m_filter_int[17] = QDate::currentDate().day();
-	m_filter_int[20] = 9999; // missing1: 18..25
-	m_filter_int[21] = 2;
-	m_filter_int[23] = QDate::currentDate().year();
-	m_filter_int[24] = QDate::currentDate().month();
-	m_filter_int[25] = QDate::currentDate().day();
-	m_filter_int[28] = 9999; // missing2: 26..33
-	m_filter_int[29] = 2;
-	m_filter_int[31] = QDate::currentDate().year();
-	m_filter_int[32] = QDate::currentDate().month();
-	m_filter_int[33] = QDate::currentDate().day();
-	m_filter_int[36] = 9999; // newer1: 34..44
-	m_filter_int[37] = 2;
-	m_filter_int[39] = QDate::currentDate().year();
-	m_filter_int[40] = QDate::currentDate().month();
-	m_filter_int[41] = QDate::currentDate().day();
-	m_filter_int[42] = 1;
-	m_filter_int[43] = 1;
-	m_filter_int[44] = 1;
-	m_filter_int[47] = 9999; // newer2: 45..55
-	m_filter_int[48] = 2;
-	m_filter_int[50] = QDate::currentDate().year();
-	m_filter_int[51] = QDate::currentDate().month();
-	m_filter_int[52] = QDate::currentDate().day();
-	m_filter_int[53] = 1;
-	m_filter_int[54] = 1;
-	m_filter_int[55] = 1;
+	m_filter_int[10] = 1;
+	
+	m_filter_int[13] = 9999; // duplicates2: 11..19
+	m_filter_int[14] = 2;
+	m_filter_int[16] = QDate::currentDate().year();
+	m_filter_int[17] = QDate::currentDate().month();
+	m_filter_int[18] = QDate::currentDate().day();
+	m_filter_int[19] = 1;
+
+	m_filter_int[22] = 9999; // missing1: 20..28
+	m_filter_int[23] = 2;
+	m_filter_int[25] = QDate::currentDate().year();
+	m_filter_int[26] = QDate::currentDate().month();
+	m_filter_int[27] = QDate::currentDate().day();
+	m_filter_int[28] = 1;
+
+	m_filter_int[31] = 9999; // missing2: 29..37
+	m_filter_int[32] = 2;
+	m_filter_int[34] = QDate::currentDate().year();
+	m_filter_int[35] = QDate::currentDate().month();
+	m_filter_int[36] = QDate::currentDate().day();
+	m_filter_int[37] = 1;
+
+	m_filter_int[40] = 9999; // newer1: 38..49
+	m_filter_int[41] = 2;
+	m_filter_int[43] = QDate::currentDate().year();
+	m_filter_int[44] = QDate::currentDate().month();
+	m_filter_int[45] = QDate::currentDate().day();
+	m_filter_int[46] = 1;
+	m_filter_int[47] = 1;
+	m_filter_int[48] = 1;
+	m_filter_int[49] = 1;
+
+	m_filter_int[52] = 9999; // newer2: 50..61
+	m_filter_int[53] = 2;
+	m_filter_int[55] = QDate::currentDate().year();
+	m_filter_int[56] = QDate::currentDate().month();
+	m_filter_int[57] = QDate::currentDate().day();
+	m_filter_int[58] = 1;
+	m_filter_int[59] = 1;
+	m_filter_int[60] = 1;
+	m_filter_int[61] = 1;
+
+	m_virtual_subfolders.clear();
 }
 
 QString KomparatorPreset::title()
@@ -153,6 +173,7 @@ bool KomparatorPreset::readConfig( uint preset_number )
 	m_md5_sum = conf->readBoolEntry( "md5_sum" );
 	m_binary_comparison = conf->readBoolEntry( "binary_comparison" );
 	m_binary_comparison_size = conf->readUnsignedNumEntry( "binary_comparison_size" ); // in MB
+	m_duplicates_right_url_only = conf->readBoolEntry( "duplicates_right_url_only" );
 	m_empty_folders = conf->readBoolEntry( "empty_folders" );
 	m_include_subfolders = conf->readBoolEntry( "include_subfolders" );
 	m_include_hidden_items = conf->readBoolEntry( "include_hidden_items" );
@@ -165,6 +186,7 @@ bool KomparatorPreset::readConfig( uint preset_number )
 	m_reference_folder_left = conf->readBoolEntry( "reference_folder_left" );
 	m_filter_string = conf->readListEntry( "filter_string" );
 	m_filter_int = conf->readIntListEntry( "filter_int" );
+	m_virtual_subfolders = conf->readListEntry( "virtual_subfolders" );
 
 	// Sanity check for values
 	if ( m_regex_contains.isEmpty() ) m_regex_contains = "*";
@@ -202,6 +224,7 @@ bool KomparatorPreset::saveConfig( uint preset_number )
 	conf->writeEntry( "md5_sum", m_md5_sum );
 	conf->writeEntry( "binary_comparison", m_binary_comparison );
 	conf->writeEntry( "binary_comparison_size", m_binary_comparison_size );
+	conf->writeEntry( "duplicates_right_url_only", m_duplicates_right_url_only );
 	conf->writeEntry( "empty_folders", m_empty_folders );
 	conf->writeEntry( "include_subfolders", m_include_subfolders );
 	conf->writeEntry( "include_hidden_items", m_include_hidden_items );
@@ -214,6 +237,9 @@ bool KomparatorPreset::saveConfig( uint preset_number )
 	conf->writeEntry( "reference_folder_left", m_reference_folder_left );
 	conf->writeEntry( "filter_string", m_filter_string );
 	conf->writeEntry( "filter_int", m_filter_int );
+	conf->writeEntry( "virtual_subfolders", m_virtual_subfolders );
+
+	conf->sync();
 
 	return true;
 }
@@ -284,6 +310,7 @@ bool KomparatorPreset::readFromInterface( bool reread )
 	m_md5_sum = m_parent->calculateChecksum_CheckBox->isChecked();
 	m_binary_comparison = m_parent->binaryComparison_CheckBox->isChecked();
 	m_binary_comparison_size = m_parent->binaryComparison_KIntSpinBox->value(); // in MB
+	m_duplicates_right_url_only = m_parent->duplicatesOnly_CheckBox->isChecked();
 	m_empty_folders = m_parent->findEmptyFolders_CheckBox->isChecked();
 	m_include_subfolders = m_parent->includeSubfolders_CheckBox->isChecked();
 	m_include_hidden_items = m_parent->includeHiddenItems_CheckBox->isChecked();
@@ -299,6 +326,7 @@ bool KomparatorPreset::readFromInterface( bool reread )
 	string_list = m_parent->duplicates1_KomparatorFileFilter->getStringList() + m_parent->duplicates2_KomparatorFileFilter->getStringList() +
 		m_parent->missing1_KomparatorFileFilter->getStringList() + m_parent->missing2_KomparatorFileFilter->getStringList() +
 		m_parent->newer1_KomparatorFileFilter->getStringList() + m_parent->newer2_KomparatorFileFilter->getStringList();
+	string_list.push_back( "EOL" );
 	m_filter_string = string_list;
 
 	QValueList<int> int_list;
@@ -307,6 +335,14 @@ bool KomparatorPreset::readFromInterface( bool reread )
 		m_parent->newer1_KomparatorFileFilter->getIntList() + m_parent->newer2_KomparatorFileFilter->getIntList();
 	m_filter_int = int_list;
 
+	KURL::List virtual_subfolders = m_parent->subfolders_KomparatorUrlList->getUrlList();
+	m_virtual_subfolders.clear();
+	KURL::List::Iterator it;
+	for ( it=virtual_subfolders.begin(); it != virtual_subfolders.end(); ++it )
+	{
+		m_virtual_subfolders.push_back( (*it).url() );
+	}
+
 	return true;
 }
 
@@ -332,6 +368,7 @@ void KomparatorPreset::setToInterface()
 	m_parent->calculateChecksum_CheckBox->setChecked( m_md5_sum );
 	m_parent->binaryComparison_CheckBox->setChecked( m_binary_comparison );
 	m_parent->binaryComparison_KIntSpinBox->setValue( m_binary_comparison_size );
+	m_parent->duplicatesOnly_CheckBox->setChecked( m_duplicates_right_url_only );
 	m_parent->findEmptyFolders_CheckBox->setChecked( m_empty_folders );
 	m_parent->includeSubfolders_CheckBox->setChecked( m_include_subfolders );
 	m_parent->includeHiddenItems_CheckBox->setChecked( m_include_hidden_items );
@@ -347,7 +384,7 @@ void KomparatorPreset::setToInterface()
 	m_parent->duplicatesReference1_RadioButton->setChecked( m_reference_folder_left );
 	m_parent->duplicatesReference2_RadioButton->setChecked( !m_reference_folder_left );
 
-	if ( m_filter_string.size() == 24 )
+	if ( m_filter_string.size() == 25 && m_filter_string[24] == "EOL" )
 	{
 		QStringList string_list;
 		string_list << m_filter_string[0] << m_filter_string[1] << m_filter_string[2] << m_filter_string[3];
@@ -369,31 +406,40 @@ void KomparatorPreset::setToInterface()
 		m_parent->newer2_KomparatorFileFilter->setStringList( string_list );
 	}
 
-	if ( m_filter_int.size() == 56 )
+	if ( m_filter_int.size() == 62 )
 	{
 		QValueList<int> int_list;
 		int_list << m_filter_int[0] << m_filter_int[1] << m_filter_int[2] << m_filter_int[3] << m_filter_int[4] <<
-			m_filter_int[5] << m_filter_int[6] << m_filter_int[7] << m_filter_int[8] << m_filter_int[9];
+			m_filter_int[5] << m_filter_int[6] << m_filter_int[7] << m_filter_int[8] << m_filter_int[9] << m_filter_int[10];
 		m_parent->duplicates1_KomparatorFileFilter->setIntList( int_list );
 		int_list.clear();
-		int_list << m_filter_int[10] << m_filter_int[11] << m_filter_int[12] << m_filter_int[13] << m_filter_int[14] <<
-			m_filter_int[15] << m_filter_int[16] << m_filter_int[17];
+		int_list << m_filter_int[11] << m_filter_int[12] << m_filter_int[13] << m_filter_int[14] << m_filter_int[15] <<
+			m_filter_int[16] << m_filter_int[17] << m_filter_int[18] << m_filter_int[19];
 		m_parent->duplicates2_KomparatorFileFilter->setIntList( int_list );
 		int_list.clear();
-		int_list << m_filter_int[18] << m_filter_int[19] << m_filter_int[20] << m_filter_int[21] << m_filter_int[22] <<
-			m_filter_int[23] << m_filter_int[24] << m_filter_int[25];
+		int_list << m_filter_int[20] << m_filter_int[21] << m_filter_int[22] << m_filter_int[23] << m_filter_int[24] <<
+			m_filter_int[25] << m_filter_int[26] << m_filter_int[27] << m_filter_int[28];
 		m_parent->missing1_KomparatorFileFilter->setIntList( int_list );
 		int_list.clear();
-		int_list << m_filter_int[26] << m_filter_int[27] << m_filter_int[28] << m_filter_int[29] << m_filter_int[30] <<
-			m_filter_int[31] << m_filter_int[32] << m_filter_int[33];
+		int_list << m_filter_int[29] << m_filter_int[30] << m_filter_int[31] << m_filter_int[32] << m_filter_int[33] <<
+			m_filter_int[34] << m_filter_int[35] << m_filter_int[36] << m_filter_int[37];
 		m_parent->missing2_KomparatorFileFilter->setIntList( int_list );
 		int_list.clear();
-		int_list << m_filter_int[34] << m_filter_int[35] << m_filter_int[36] << m_filter_int[37] << m_filter_int[38] <<
-			m_filter_int[39] << m_filter_int[40] << m_filter_int[41] << m_filter_int[42] << m_filter_int[43] << m_filter_int[44];
+		int_list << m_filter_int[38] << m_filter_int[39] << m_filter_int[40] << m_filter_int[41] << m_filter_int[42] <<
+			m_filter_int[43] << m_filter_int[44] << m_filter_int[45] << m_filter_int[46] << m_filter_int[47] <<
+				m_filter_int[48] << m_filter_int[49];
 		m_parent->newer1_KomparatorFileFilter->setIntList( int_list );
 		int_list.clear();
-		int_list << m_filter_int[45] << m_filter_int[46] << m_filter_int[47] << m_filter_int[48] << m_filter_int[49] <<
-			m_filter_int[50] << m_filter_int[51] << m_filter_int[52] << m_filter_int[53] << m_filter_int[54] << m_filter_int[55];
+		int_list << m_filter_int[50] << m_filter_int[51] << m_filter_int[52] << m_filter_int[53] << m_filter_int[54] <<
+			m_filter_int[55] << m_filter_int[56] << m_filter_int[57] << m_filter_int[58] << m_filter_int[59] <<
+				m_filter_int[60] << m_filter_int[61];
 		m_parent->newer2_KomparatorFileFilter->setIntList( int_list );
 	}
+
+	m_parent->subfolders_KomparatorUrlList->clear();
+	QStringList::Iterator it;
+	for ( it=m_virtual_subfolders.begin(); it!=m_virtual_subfolders.end(); ++it )
+	{
+		m_parent->subfolders_KomparatorUrlList->addUrl( KURL( *it ) );
+	}
 }
